@@ -35,7 +35,6 @@ if ($EVAL_ERROR) {
 # GraphViz object.
 my $g = Map::Tube::GraphViz->new(
         'callback_node' => \&node_color_without_label,
-        'driver' => 'neato',
         'tube' => $tube,
 );
 
@@ -49,4 +48,4 @@ system "ls -l $metro.png";
 # Usage: /tmp/SZXfa2g154 metro
 
 # Output with 'Berlin' argument like:
-# -rw-r--r-- 1 skim skim 1503518 Dec 17 01:10 Berlin.png
\ No newline at end of file
+# -rw-r--r-- 1 skim skim 885928 Jan 27 07:43 Berlin.png
\ No newline at end of file
